pub struct Settings { /* private fields */ }Expand description
Settings are used to configure the Hll and how it transitions between the backing storage types.
Implementations
Sourceimpl Settings
impl Settings
pub fn new( log_2m: u32, reg_width: u32, explicit_threshold: i32, sparse_enabled: bool, ) -> Result<Self, SettingsError>
pub fn validate(&self) -> Result<(), SettingsError>
pub fn settings_check(&self, other: &Self) -> Result<(), SettingsError>
pub fn explicit_threshold(&self) -> u32
Sourcepub fn calculate_explicit_threshold(log_2m: u32, reg_width: u32) -> u32
pub fn calculate_explicit_threshold(log_2m: u32, reg_width: u32) -> u32
determines a good cutoff to switch between explicit and probabilistic storage.